@@ -143,7 +143,7 @@ struct post_correction
 
 struct jump_shot
 {
-    int found;
+    _Bool found;
     Vector best_shot_vector;
     struct post_correction targets;
 };
@@ -320,7 +320,7 @@ struct jump_viable_dat jump_is_viable(double T, double boost_accel, double dista
 struct jump_shot parse_slice_for_jump_shot_with_target(double time_remaining, double best_shot_value, Vector ball_location, Vector car_location, Vector car_forward, int car_boost, Vector left_target, Vector right_target, double boost_accel, double car_speed)
 {
     struct jump_shot r;
-    r.found = -1;
+    r.found = 0;
 
     Vector car_to_ball = sub(ball_location, car_location);
     struct opti_norm car_to_ball_norm = normalize(car_to_ball);
@@ -336,9 +336,12 @@ struct jump_shot parse_slice_for_jump_shot_with_target(double time_remaining, do
         if (in_field(sub(ball_location, multiply(r.best_shot_vector, double_to_vector(best_shot_value))), 1))
         {
             double slope = find_slope(r.best_shot_vector, car_to_ball);
-            struct jump_viable_dat is_viable = jump_is_viable(time_remaining, boost_accel, car_to_ball_norm.magnitude, r.best_shot_vector, car_forward, car_boost, car_speed);
-            if ((is_viable.forward && slope > 0) || (is_viable.backward && slope > 0.5))
-                r.found = 1;
+            if (slope > 0) {
+                struct jump_viable_dat is_viable = jump_is_viable(time_remaining, boost_accel, car_to_ball_norm.magnitude, direction, car_forward, car_boost, car_speed);
+
+                if (is_viable.forward || (is_viable.backward && slope > 0.5))
+                    r.found = 1;
+            }
         }
     }
 
@@ -348,21 +351,22 @@ struct jump_shot parse_slice_for_jump_shot_with_target(double time_remaining, do
 struct jump_shot parse_slice_for_jump_shot(double time_remaining, double best_shot_value, Vector ball_location, Vector car_location, Vector car_forward, int car_boost, double boost_accel, double car_speed)
 {
     struct jump_shot r;
-    r.found = -1;
+    r.found = 0;
 
     Vector car_to_ball = sub(ball_location, car_location);
     struct opti_norm car_to_ball_norm = normalize(car_to_ball);
     Vector direction = car_to_ball_norm.vector;
 
-    struct jump_viable_dat is_viable = jump_is_viable(time_remaining, boost_accel, car_to_ball_norm.magnitude, direction, car_forward, car_boost, car_speed);
-
     r.best_shot_vector = direction;
 
-    if ((is_viable.forward || is_viable.backward) && in_field(sub(ball_location, multiply(r.best_shot_vector, double_to_vector(best_shot_value))), 1))
+    if (in_field(sub(ball_location, multiply(r.best_shot_vector, double_to_vector(best_shot_value))), 1))
     {
         double slope = find_slope(r.best_shot_vector, car_to_ball);
-        if ((is_viable.forward && slope > 0) || (is_viable.backward && slope > 0.5))
-            r.found = 1;
+        if (slope > 0) {
+            struct jump_viable_dat is_viable = jump_is_viable(time_remaining, boost_accel, car_to_ball_norm.magnitude, direction, car_forward, car_boost, car_speed);
+            if (is_viable.forward || (is_viable.backward && slope > 0.5))
+                r.found = 1;
+        }
     }
 
     return r;
@@ -381,7 +385,7 @@ _Bool double_jump_is_viable(double T, double boost_accel, double distance, Vecto
 struct jump_shot parse_slice_for_double_jump_with_target(double time_remaining, double best_shot_value, Vector ball_location, Vector car_location, Vector car_forward, int car_boost, Vector left_target, Vector right_target, double boost_accel, double car_speed)
 {
     struct jump_shot r;
-    r.found = -1;
+    r.found = 0;
 
     Vector car_to_ball = sub(ball_location, car_location);
     struct opti_norm car_to_ball_norm = normalize(car_to_ball);
@@ -395,7 +399,7 @@ struct jump_shot parse_slice_for_double_jump_with_target(double time_remaining,
         r.best_shot_vector = clamp2D(direction, left_vector, right_vector);
 
         if (in_field(sub(ball_location, multiply(r.best_shot_vector, double_to_vector(best_shot_value))), 1) && find_slope(r.best_shot_vector, car_to_ball) > 0.5)
-            r.found = double_jump_is_viable(time_remaining, boost_accel, car_to_ball_norm.magnitude, r.best_shot_vector, car_forward, car_boost, car_speed);
+            r.found = double_jump_is_viable(time_remaining, boost_accel, car_to_ball_norm.magnitude, direction, car_forward, car_boost, car_speed);
     }
 
     return r;
@@ -404,17 +408,16 @@ struct jump_shot parse_slice_for_double_jump_with_target(double time_remaining,
 struct jump_shot parse_slice_for_double_jump(double time_remaining, double best_shot_value, Vector ball_location, Vector car_location, Vector car_forward, int car_boost, double boost_accel, double car_speed)
 {
     struct jump_shot r;
-    r.found = -1;
+    r.found = 0;
 
     Vector car_to_ball = sub(ball_location, car_location);
     struct opti_norm car_to_ball_norm = normalize(car_to_ball);
     Vector direction = car_to_ball_norm.vector;
 
     r.best_shot_vector = direction;
-    r.best_shot_vector.z = 0;
 
-    if (double_jump_is_viable(time_remaining, boost_accel, car_to_ball_norm.magnitude, direction, car_forward, car_boost, car_speed) && in_field(sub(ball_location, multiply(r.best_shot_vector, double_to_vector(best_shot_value))), 1) && find_slope(r.best_shot_vector, car_to_ball) > 0.5)
-        r.found = 1;
+    if (in_field(sub(ball_location, multiply(r.best_shot_vector, double_to_vector(best_shot_value))), 1) && find_slope(r.best_shot_vector, car_to_ball) > 0.5)
+        r.found = double_jump_is_viable(time_remaining, boost_accel, car_to_ball_norm.magnitude, direction, car_forward, car_boost, car_speed);
 
     return r;
 };
@@ -505,7 +508,7 @@ struct aerial_shot aerial_is_viable(double time_remaining, double hitbox_height,
 struct aerial_shot parse_slice_for_aerial_shot_with_target(double time_remaining, double best_shot_value, double boost_accel, Vector gravity, Vector ball_location, struct car me, Vector left_target, Vector right_target)
 {
     struct aerial_shot r;
-    r.found = -1;
+    r.found = 0;
 
     Vector car_to_ball = sub(ball_location, me.location);
     Vector direction = normalize(car_to_ball).vector;
@@ -537,7 +540,7 @@ struct aerial_shot parse_slice_for_aerial_shot_with_target(double time_remaining
 struct aerial_shot parse_slice_for_aerial_shot(double time_remaining, double best_shot_value, double boost_accel, Vector gravity, Vector ball_location, struct car me)
 {
     struct aerial_shot r;
-    r.found = -1;
+    r.found = 0;
 
     Vector car_to_ball = sub(ball_location, me.location);
 
